<?php

/* Onpub (TM)
 * Copyright (C) 2009 Onpubco <http://onpubco.com/>
 * Author: Corey H.M. Taylor <corey@onpubco.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; version 2.
 */

header("Content-Type: text/html; charset=iso-8859-1");

session_name("onpubsite");
session_set_cookie_params(0);
session_start();

if (isset($_GET['websiteID'])) {
  if (!ctype_digit($_GET['websiteID'])) {
    en('<span style="color: red;">websiteID must be an integer.</span>');
    exit;
  }

  $websiteID = $_GET['websiteID'];
  $_SESSION["wID"] = $websiteID;
}

if (isset($_SESSION["wID"])) {
  $websiteID = $_SESSION["wID"];
}

try {
  $pdo = new PDO('mysql:host=' . $dbHost . ';dbname=' . $dbName, $dbUser, $dbPass);
}
catch (PDOException $e) {
  en('<span style="color: red;">' . $e->getMessage() . '</span>');
  exit;
}

$website = NULL;
$section = NULL;
$article = NULL;

$ow = new OnpubWebsites($pdo);
$oa = new OnpubArticles($pdo);
$os = new OnpubSections($pdo);

$qo = new OnpubQueryOptions();
$qo->includeSections = TRUE;
$qo->includeArticles = TRUE;
$qo->includeContent = FALSE;

try {
  $website = $ow->get($websiteID, $qo);
}
catch (PDOException $e) {
  en('<span style="color: red;">' . $e->getMessage() . '</span>');
  exit;
}

if (!$website) {
  en('<span style="color: red;">Website ' . $websiteID .
    ' does not exist.</span>');
  exit;
}

$index = 'home';

if (isset($_GET['sectionID']) && !isset($_GET['articleID'])) {
  if (!ctype_digit($_GET['sectionID'])) {
    en('<span style="color: red;">sectionID must be an integer.</span>');
    exit;
  }

  $qo = new OnpubQueryOptions();
  $qo->includeArticles = TRUE;
  $qo->includeContent = FALSE;
  $qo->includeAuthors = TRUE;
  $qo->orderBy = "created";
  $qo->order = "DESC";

  try {
    $section = $os->get($_GET['sectionID'], $qo);
  }
  catch (PDOException $e) {
    en('<span style="color: red;">' . $e->getMessage() . '</span>');
    exit;
  }

  $index = 'section';
}
elseif (!isset($_GET['sectionID']) && isset($_GET['articleID'])) {
  if (!ctype_digit($_GET['articleID'])) {
    en('<span style="color: red;">articleID must be an integer.</span>');
    exit;
  }

  $qo = new OnpubQueryOptions();
  $qo->includeAuthors = TRUE;

  try {
    $article = $oa->get($_GET['articleID'], $qo);
  }
  catch (PDOException $e) {
    en('<span style="color: red;">' . $e->getMessage() . '</span>');
    exit;
  }

  $index = 'article';
}
elseif (isset($_GET['sectionID']) && isset($_GET['articleID'])) {
  if (!ctype_digit($_GET['sectionID'])) {
    en('<span style="color: red;">sectionID must be an integer.</span>');
    exit;
  }

  if (!ctype_digit($_GET['articleID'])) {
    en('<span style="color: red;">articleID must be an integer.</span>');
    exit;
  }

  $qo = new OnpubQueryOptions();
  $qo->includeAuthors = TRUE;

  try {
    $section = $os->get($_GET['sectionID']);
    $article = $oa->get($_GET['articleID'], $qo);
  }
  catch (PDOException $e) {
    en('<span style="color: red;">' . $e->getMessage() . '</span>');
    exit;
  }

  $index = 'section-article';
}
?>